@@ -1,32 +1,32 @@
-package htsjdk.beta.codecs.variants.vcf.vcfv3_2;
+package htsjdk.beta.codecs.variants.vcf.vcfv4_2;
 
 import htsjdk.beta.codecs.variants.vcf.VCFCodec;
 import htsjdk.beta.codecs.variants.vcf.VCFDecoder;
 import htsjdk.beta.codecs.variants.vcf.VCFEncoder;
 import htsjdk.beta.exception.HtsjdkUnsupportedOperationException;
-import htsjdk.beta.plugin.HtsVersion;
 import htsjdk.beta.io.bundle.Bundle;
+import htsjdk.beta.plugin.HtsVersion;
 import htsjdk.beta.plugin.variants.VariantsDecoderOptions;
 import htsjdk.beta.plugin.variants.VariantsEncoderOptions;
 import htsjdk.utils.ValidationUtils;
 
 /**
- * VCF V3.2 codec.
+ * VCF V4.2 codec.
  */
-public class VCFCodecV3_2 extends VCFCodec {
-    public static final HtsVersion VCF_V32_VERSION = new HtsVersion(3,2,0);
+public class VCFCodecV4_2 extends VCFCodec {
+    public static final HtsVersion VCF_V42_VERSION = new HtsVersion(4,2,0);
 
-    private static final String VCF_V32_MAGIC = "##format=VCRv3.2";
+    private static final String VCF_V42_MAGIC = "##fileformat=VCFv4.2";
 
     @Override
-    public HtsVersion getVersion() { return VCF_V32_VERSION; }
+    public HtsVersion getVersion() { return VCF_V42_VERSION; }
 
     @Override
     public VCFDecoder getDecoder(final Bundle inputBundle, final VariantsDecoderOptions decoderOptions) {
         ValidationUtils.nonNull(inputBundle, "inputBundle");
         ValidationUtils.nonNull(decoderOptions, "decoderOptions");
 
-        return new VCFDecoderV3_2(inputBundle, decoderOptions);
+        return new VCFDecoderV4_2(inputBundle, decoderOptions);
     }
 
     @Override
@@ -34,7 +34,7 @@ public class VCFCodecV3_2 extends VCFCodec {
         ValidationUtils.nonNull(outputBundle, "outputBundle");
         ValidationUtils.nonNull(encoderOptions, "encoderOptions");
 
-        return new VCFEncoderV3_2(outputBundle, encoderOptions);
+        return new VCFEncoderV4_2(outputBundle, encoderOptions);
     }
 
     @Override
@@ -43,6 +43,6 @@ public class VCFCodecV3_2 extends VCFCodec {
     }
 
     @Override
-    protected String getSignatureString() { return VCF_V32_MAGIC; }
+    protected String getSignatureString() { return VCF_V42_MAGIC; }
 
 }
