@@ -1,5 +1,6 @@
 package htsjdk.beta.plugin.registry;
 
+import htsjdk.beta.codecs.reads.cram.cramV3_1.CRAMCodecV3_1;
 import htsjdk.beta.exception.HtsjdkException;
 import htsjdk.beta.exception.HtsjdkPluginException;
 import htsjdk.beta.plugin.HtsVersion;
@@ -11,9 +12,13 @@ import htsjdk.beta.plugin.reads.ReadsDecoder;
 import htsjdk.beta.plugin.reads.ReadsDecoderOptions;
 import htsjdk.beta.plugin.reads.ReadsEncoder;
 import htsjdk.beta.plugin.reads.ReadsEncoderOptions;
+import htsjdk.beta.plugin.reads.ReadsFormats;
 import htsjdk.io.IOPath;
 import htsjdk.utils.ValidationUtils;
 
+import java.util.List;
+import java.util.stream.Collectors;
+
 /**
  * Class with methods for resolving inputs and outputs to reads encoders and decoders.
  * <p>
@@ -204,6 +209,30 @@ public class ReadsResolver extends HtsCodecResolver<ReadsCodec>{
                 .getEncoder(outputBundle, readsEncoderOptions);
     }
 
+    /**
+     * Temporarily override to remove the CRAM 3.1 codec from the list of candidate codecs when the request is for
+     * the newest version, since it has no write implementation yet.
+     */
+    @Override
+    protected List<ReadsCodec> filterByVersion(final List<ReadsCodec> candidateCodecs, final HtsVersion htsVersion) {
+        final List<ReadsCodec> preFilteredCodecs;
+        if (htsVersion.equals(HtsVersion.NEWEST_VERSION)) {
+            // if the request is for the newest version, then pre-filter out the CRAM 3.1 codec since it has no
+            // write implementation yet, and then delegate to the superclass to let it find the newest version among
+            // the remaining codecs
+            preFilteredCodecs = candidateCodecs.stream().filter(
+                    c -> !(c.getFileFormat().equals(ReadsFormats.CRAM)
+                            && c.getVersion().equals(CRAMCodecV3_1.VERSION_3_1)))
+                    .collect(Collectors.toList());
+            final HtsVersion newestVersion = preFilteredCodecs.stream()
+                    .map(c -> c.getVersion())
+                    .reduce(candidateCodecs.get(0).getVersion(),
+                            (HtsVersion a, HtsVersion b) -> a.compareTo(b) > 0 ? a : b);
+            return candidateCodecs.stream().filter(
+                    c -> c.getVersion().equals(newestVersion)).collect(Collectors.toList());
+        } else {
+            preFilteredCodecs = candidateCodecs;
+        }
+        return super.filterByVersion(preFilteredCodecs, htsVersion);
+    }
 }
-
-
