@@ -18,6 +18,7 @@
 package htsjdk.samtools.cram.encoding.readfeatures;
 
 import java.io.Serializable;
+import java.util.Objects;
 
 /**
  * A substitution event captured in read coordinates. It is characterized by position in read, read base and reference base.
@@ -27,6 +28,7 @@ import java.io.Serializable;
  */
 public class Substitution implements Serializable, ReadFeature {
     public static final int NO_CODE = -1;
+    public static final byte operator = 'X';
 
     /**
      * zero-based position in read
@@ -45,13 +47,19 @@ public class Substitution implements Serializable, ReadFeature {
      */
     private byte code = NO_CODE;
 
-    public Substitution() {
+    // Substitutions have two manifestations; just a raw code that can be mapped to a base in a
+    // {@link SusbtitutionMatrix}, or a base and reference base that can be mapped to a code in
+    // a {@link SusbtitutionMatrix}
+    public Substitution(final int position, final byte code) {
+        this.position = position;
+        this.code = code;
     }
 
     public Substitution(int position, byte base, byte referenceBase) {
         this.position = position;
         this.base = base;
         this.referenceBase = referenceBase;
+        this.code = NO_CODE;
     }
 
     public byte getCode() {
@@ -62,8 +70,6 @@ public class Substitution implements Serializable, ReadFeature {
         this.code = code;
     }
 
-    public static final byte operator = 'X';
-
     @Override
     public byte getOperator() {
         return operator;
@@ -74,27 +80,14 @@ public class Substitution implements Serializable, ReadFeature {
         return position;
     }
 
-    @Override
-    public void setPosition(final int position) {
-        this.position = position;
-    }
-
     public byte getBase() {
         return base;
     }
 
-    public void setBase(final byte base) {
-        this.base = base;
-    }
-
     public byte getReferenceBase() {
         return referenceBase;
     }
 
-    public void setReferenceBase(final byte referenceBase) {
-        this.referenceBase = referenceBase;
-    }
-
     @Override
     public boolean equals(final Object obj) {
         if (!(obj instanceof Substitution))
@@ -116,6 +109,14 @@ public class Substitution implements Serializable, ReadFeature {
         return true;
     }
 
+    @Override
+    public int hashCode() {
+        if (code == NO_CODE) {
+            return Objects.hash(position);
+        }
+        return Objects.hash(position, base, referenceBase);
+    }
+
     @Override
     public String toString() {
         return String.valueOf((char) operator) + '@' + position + '\\' + (char) base + (char) referenceBase;
