@@ -17,13 +17,13 @@
  */
 package htsjdk.samtools.cram.structure;
 
-import htsjdk.samtools.cram.common.Version;
+import htsjdk.samtools.cram.CRAMException;
+import htsjdk.samtools.cram.common.CRAMVersion;
 import htsjdk.samtools.cram.compression.ExternalCompressor;
 import htsjdk.samtools.cram.io.ITF8;
 import htsjdk.samtools.cram.io.InputStreamUtils;
 import htsjdk.samtools.cram.structure.block.Block;
 import htsjdk.samtools.cram.structure.block.BlockContentType;
-import htsjdk.samtools.util.Log;
 import htsjdk.samtools.util.RuntimeIOException;
 
 import java.io.ByteArrayInputStream;
@@ -32,12 +32,7 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.nio.ByteBuffer;
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
-import java.util.TreeMap;
+import java.util.*;
 
 public class CompressionHeader {
     private static final String RN_readNamesIncluded = "RN";
@@ -46,48 +41,158 @@ public class CompressionHeader {
     private static final String TD_tagIdsDictionary = "TD";
     private static final String SM_substitutionMatrix = "SM";
 
-    private static final Log log = Log.getInstance(CompressionHeader.class);
-
-    public boolean readNamesIncluded;
-    public boolean APDelta = true;
+    private CompressionHeaderEncodingMap encodingMap;
+    // these all default to true, per the spec
+    private boolean APDelta = true;
+    private boolean preserveReadNames = true;
     private boolean referenceRequired = true;
 
-    public Map<DataSeries, EncodingParams> encodingMap;
-    public Map<Integer, EncodingParams> tMap;
-    public final Map<Integer, ExternalCompressor> externalCompressors = new HashMap<Integer, ExternalCompressor>();
-
-    public SubstitutionMatrix substitutionMatrix;
-
-    public List<Integer> externalIds;
-
-    public byte[][][] dictionary;
+    // ContentID to tage series EncodingDescriptor. For tags, the content ID is defined
+    // by to be a value derived from the tag data type and name (see @link #ReadTag.name3BytesToInt).
+    private final Map<Integer, EncodingDescriptor> tagEncodingMap = new TreeMap<>();
+    private SubstitutionMatrix substitutionMatrix;
+    private byte[][][] tagIDDictionary;
 
+    /**
+     * Create a CompressionHeader using the default {@link CRAMEncodingStrategy}
+     */
     public CompressionHeader() {
+        encodingMap = new CompressionHeaderEncodingMap(new CRAMEncodingStrategy());
+    }
+
+    public CompressionHeader(
+            final CompressionHeaderEncodingMap encodingMap,
+            final boolean isAPDelta,
+            final boolean isPreserveReadNames,
+            final boolean isReferenceRequired) {
+        this.encodingMap = encodingMap;
+        this.APDelta = isAPDelta;
+        this.preserveReadNames = isPreserveReadNames;
+        this.referenceRequired = isReferenceRequired;
+    }
+
+    /**
+     * Create a compression header using the given {@link CompressionHeaderEncodingMap}.
+     * @param encodingMap the encoding map to use for this compression header
+     */
+    public CompressionHeader(final CompressionHeaderEncodingMap encodingMap) {
+        this.encodingMap = encodingMap;
+    }
+
+    /**
+     * Read a COMPRESSION_HEADER Block from an InputStream and return its contents as a CompressionHeader.
+     *
+     * @param cramVersion the CRAM version
+     * @param blockStream the stream to read from
+     * @return a new CompressionHeader
+     */
+    public CompressionHeader(final CRAMVersion cramVersion, final InputStream blockStream) {
+        final Block compressionHeaderBlock = Block.read(cramVersion, blockStream);
+        if (compressionHeaderBlock.getContentType() != BlockContentType.COMPRESSION_HEADER) {
+            throw new RuntimeIOException(
+                    String.format("Compression header block expected, found: %s",
+                            compressionHeaderBlock.getContentType().name()));
+        }
+
+        // get raw content since compression headers are always raw...
+        try (final ByteArrayInputStream internalStream = new ByteArrayInputStream(compressionHeaderBlock.getRawContent())) {
+            internalRead(internalStream);
+        } catch (final IOException e) {
+            throw new RuntimeIOException(e);
+        }
+    }
+
+    /**
+     * Get the {@link CompressionHeaderEncodingMap} for this compression header.
+     * @return {@link CompressionHeaderEncodingMap} for this {@link CompressionHeader}
+     */
+    public CompressionHeaderEncodingMap getEncodingMap() { return encodingMap; }
+
+    /**
+     * Write this CompressionHeader out to an internal OutputStream, wrap it in a Block, and write that
+     * Block out to the passed-in OutputStream.
+     *
+     * @param cramVersion the CRAM version
+     * @param blockStream the stream to write to
+     */
+    public void write(final CRAMVersion cramVersion, final OutputStream blockStream) {
+        try (final ByteArrayOutputStream internalOutputStream = new ByteArrayOutputStream()) {
+            internalWrite(internalOutputStream);
+            final Block block = Block.createRawCompressionHeaderBlock(internalOutputStream.toByteArray());
+            block.write(cramVersion, blockStream);
+        }
+        catch (final IOException e) {
+            throw new RuntimeIOException(e);
+        }
+    }
+
+    /**
+     * Return true if the header has APDelta set. Coordinate sorted input will use APDelta=true, but
+     * it is also permitted for other sort orders to use APDelta=true.
+     * @return the value of the APDelta flag
+     */
+    public boolean isAPDelta() {
+        return APDelta;
+    }
+
+    public boolean isPreserveReadNames() {
+        return preserveReadNames;
+    }
+
+    public Map<Integer, EncodingDescriptor> getTagEncodingMap() {
+        return tagEncodingMap;
+    }
+
+    public SubstitutionMatrix getSubstitutionMatrix() {
+        return substitutionMatrix;
+    }
+
+    public byte[][][] getTagIDDictionary() {
+        return tagIDDictionary;
+    }
+
+    public  void setTagIdDictionary(final byte[][][] dictionary) {
+        this.tagIDDictionary = dictionary;
+    }
+
+    public void setSubstitutionMatrix(final SubstitutionMatrix substitutionMatrix) {
+        this.substitutionMatrix = substitutionMatrix;
+    }
+
+    /**
+     * @return true if RR is set on this compression header
+     */
+    public boolean isReferenceRequired() {
+        return referenceRequired;
+    }
+
+    public void addTagEncoding(final int tagId, final ExternalCompressor compressor, final EncodingDescriptor params) {
+        encodingMap.putTagBlockCompression(tagId, compressor);
+        tagEncodingMap.put(tagId, params);
     }
 
     private byte[][][] parseDictionary(final byte[] bytes) {
         final List<List<byte[]>> dictionary = new ArrayList<List<byte[]>>();
-        {
-            int i = 0;
-            while (i < bytes.length) {
-                final List<byte[]> list = new ArrayList<byte[]>();
-                while (bytes[i] != 0) {
-                    list.add(Arrays.copyOfRange(bytes, i, i + 3));
-                    i += 3;
-                }
-                i++;
-                dictionary.add(list);
+        int i = 0;
+        while (i < bytes.length) {
+            final List<byte[]> list = new ArrayList<byte[]>();
+            while (bytes[i] != 0) {
+                list.add(Arrays.copyOfRange(bytes, i, i + 3));
+                i += 3;
             }
+            i++;
+            dictionary.add(list);
         }
 
         int maxWidth = 0;
-        for (final List<byte[]> list : dictionary)
+        for (final List<byte[]> list : dictionary) {
             maxWidth = Math.max(maxWidth, list.size());
+        }
 
         final byte[][][] array = new byte[dictionary.size()][][];
-        for (int i = 0; i < dictionary.size(); i++) {
-            final List<byte[]> list = dictionary.get(i);
-            array[i] = list.toArray(new byte[list.size()][]);
+        for (int j = 0; j < dictionary.size(); j++) {
+            final List<byte[]> list = dictionary.get(j);
+            array[j] = list.toArray(new byte[list.size()][]);
         }
 
         return array;
@@ -95,26 +200,26 @@ public class CompressionHeader {
 
     private byte[] dictionaryToByteArray() {
         int size = 0;
-        for (final byte[][] dictionaryArrayArray : dictionary) {
-            for (final byte[] dictionaryArray : dictionaryArrayArray) size += dictionaryArray.length;
+        for (final byte[][] dictionaryArrayArray : tagIDDictionary) {
+            for (final byte[] dictionaryArray : dictionaryArrayArray) {
+                size += dictionaryArray.length;
+            }
             size++;
         }
 
         final byte[] bytes = new byte[size];
         final ByteBuffer buffer = ByteBuffer.wrap(bytes);
-        for (final byte[][] dictionaryArrayArray : dictionary) {
-            for (final byte[] dictionaryArray : dictionaryArrayArray) buffer.put(dictionaryArray);
+        for (final byte[][] dictionaryArrayArray : tagIDDictionary) {
+            for (final byte[] dictionaryArray : dictionaryArrayArray) {
+                buffer.put(dictionaryArray);
+            }
             buffer.put((byte) 0);
         }
 
         return bytes;
     }
 
-    public byte[][] getTagIds(final int id) {
-        return dictionary[id];
-    }
-
-    private void internalRead(final InputStream is) throws IOException {
+    private void internalRead(final InputStream is) {
         { // preservation map:
             final int byteSize = ITF8.readUnsignedITF8(is);
             final byte[] bytes = new byte[byteSize];
@@ -125,7 +230,7 @@ public class CompressionHeader {
             for (int i = 0; i < mapSize; i++) {
                 final String key = new String(new byte[]{buffer.get(), buffer.get()});
                 if (RN_readNamesIncluded.equals(key))
-                    readNamesIncluded = buffer.get() == 1;
+                    preserveReadNames = buffer.get() == 1;
                 else if (AP_alignmentPositionIsDelta.equals(key))
                     APDelta = buffer.get() == 1;
                 else if (RR_referenceRequired.equals(key))
@@ -134,43 +239,24 @@ public class CompressionHeader {
                     final int size = ITF8.readUnsignedITF8(buffer);
                     final byte[] dictionaryBytes = new byte[size];
                     buffer.get(dictionaryBytes);
-                    dictionary = parseDictionary(dictionaryBytes);
+                    tagIDDictionary = parseDictionary(dictionaryBytes);
                 } else if (SM_substitutionMatrix.equals(key)) {
                     // parse subs matrix here:
-                    final byte[] matrixBytes = new byte[5];
+                    final byte[] matrixBytes = new byte[SubstitutionMatrix.BASES_SIZE];
                     buffer.get(matrixBytes);
                     substitutionMatrix = new SubstitutionMatrix(matrixBytes);
-                } else
-                    throw new RuntimeException("Unknown preservation map key: "
-                            + key);
+                } else {
+                    throw new RuntimeException("Unknown preservation map key: " + key);
+                }
+            }
+            if (substitutionMatrix == null || tagIDDictionary == null) {
+                throw new CRAMException(
+                        "substitution matrix and tag ID dictionary must be present in the compression header");
             }
         }
 
-        { // encoding map:
-            final int byteSize = ITF8.readUnsignedITF8(is);
-            final byte[] bytes = new byte[byteSize];
-            InputStreamUtils.readFully(is, bytes, 0, bytes.length);
-            final ByteBuffer buffer = ByteBuffer.wrap(bytes);
-
-            final int mapSize = ITF8.readUnsignedITF8(buffer);
-            encodingMap = new TreeMap<>();
-
-            for (int i = 0; i < mapSize; i++) {
-                final String dataSeriesAbbreviation = new String(new byte[]{buffer.get(), buffer.get()});
-                final DataSeries dataSeries = DataSeries.byCanonicalName(dataSeriesAbbreviation);
-
-                final EncodingID id = EncodingID.values()[buffer.get()];
-                final int paramLen = ITF8.readUnsignedITF8(buffer);
-                final byte[] paramBytes = new byte[paramLen];
-                buffer.get(paramBytes);
-
-                encodingMap.put(dataSeries, new EncodingParams(id, paramBytes));
-
-                log.debug(String.format("FOUND ENCODING: %s, %s, %s.",
-                        dataSeries.name(), id.name(),
-                        Arrays.toString(Arrays.copyOf(paramBytes, 20))));
-            }
-        }
+        // encoding map:
+        encodingMap = new CompressionHeaderEncodingMap(is);
 
         { // tag encoding map:
             final int byteSize = ITF8.readUnsignedITF8(is);
@@ -179,7 +265,6 @@ public class CompressionHeader {
             final ByteBuffer buf = ByteBuffer.wrap(bytes);
 
             final int mapSize = ITF8.readUnsignedITF8(buf);
-            tMap = new TreeMap<Integer, EncodingParams>();
             for (int i = 0; i < mapSize; i++) {
                 final int key = ITF8.readUnsignedITF8(buf);
 
@@ -188,37 +273,18 @@ public class CompressionHeader {
                 final byte[] paramBytes = new byte[paramLen];
                 buf.get(paramBytes);
 
-                tMap.put(key, new EncodingParams(id, paramBytes));
+                tagEncodingMap.put(key, new EncodingDescriptor(id, paramBytes));
             }
         }
     }
 
-    /**
-     * Write this CompressionHeader out to an internal OutputStream, wrap it in a Block, and write that
-     * Block out to the passed-in OutputStream.
-     *
-     * @param cramVersion the CRAM major version number
-     * @param blockStream the stream to write to
-     */
-    public void write(final Version cramVersion, final OutputStream blockStream) {
-        try (final ByteArrayOutputStream internalOutputStream = new ByteArrayOutputStream()) {
-            internalWrite(internalOutputStream);
-            final Block block = Block.createRawCompressionHeaderBlock(internalOutputStream.toByteArray());
-            block.write(cramVersion.major, blockStream);
-        }
-        catch (final IOException e) {
-            throw new RuntimeIOException(e);
-        }
-    }
-
     private void internalWrite(final OutputStream outputStream) throws IOException {
-
         { // preservation map:
             final ByteBuffer mapBuffer = ByteBuffer.allocate(1024 * 100);
             ITF8.writeUnsignedITF8(5, mapBuffer);
 
             mapBuffer.put(RN_readNamesIncluded.getBytes());
-            mapBuffer.put((byte) (readNamesIncluded ? 1 : 0));
+            mapBuffer.put((byte) (preserveReadNames ? 1 : 0));
 
             mapBuffer.put(AP_alignmentPositionIsDelta.getBytes());
             mapBuffer.put((byte) (APDelta ? 1 : 0));
@@ -230,11 +296,9 @@ public class CompressionHeader {
             mapBuffer.put(substitutionMatrix.getEncodedMatrix());
 
             mapBuffer.put(TD_tagIdsDictionary.getBytes());
-            {
-                final byte[] dictionaryBytes = dictionaryToByteArray();
-                ITF8.writeUnsignedITF8(dictionaryBytes.length, mapBuffer);
-                mapBuffer.put(dictionaryBytes);
-            }
+            final byte[] dictionaryBytes = dictionaryToByteArray();
+            ITF8.writeUnsignedITF8(dictionaryBytes.length, mapBuffer);
+            mapBuffer.put(dictionaryBytes);
 
             mapBuffer.flip();
             final byte[] mapBytes = new byte[mapBuffer.limit()];
@@ -244,46 +308,18 @@ public class CompressionHeader {
             outputStream.write(mapBytes);
         }
 
-        { // encoding map:
-            int size = 0;
-            for (final DataSeries dataSeries : encodingMap.keySet()) {
-                if (encodingMap.get(dataSeries).id != EncodingID.NULL)
-                    size++;
-            }
-
-            final ByteBuffer mapBuffer = ByteBuffer.allocate(1024 * 100);
-            ITF8.writeUnsignedITF8(size, mapBuffer);
-            for (final DataSeries dataSeries : encodingMap.keySet()) {
-                if (encodingMap.get(dataSeries).id == EncodingID.NULL)
-                    continue;
-
-                final String dataSeriesAbbreviation = dataSeries.getCanonicalName();
-                mapBuffer.put((byte) dataSeriesAbbreviation.charAt(0));
-                mapBuffer.put((byte) dataSeriesAbbreviation.charAt(1));
-
-                final EncodingParams params = encodingMap.get(dataSeries);
-                mapBuffer.put((byte) (0xFF & params.id.getId()));
-                ITF8.writeUnsignedITF8(params.params.length, mapBuffer);
-                mapBuffer.put(params.params);
-            }
-            mapBuffer.flip();
-            final byte[] mapBytes = new byte[mapBuffer.limit()];
-            mapBuffer.get(mapBytes);
-
-            ITF8.writeUnsignedITF8(mapBytes.length, outputStream);
-            outputStream.write(mapBytes);
-        }
+        encodingMap.write(outputStream);
 
         { // tag encoding map:
             final ByteBuffer mapBuffer = ByteBuffer.allocate(1024 * 100);
-            ITF8.writeUnsignedITF8(tMap.size(), mapBuffer);
-            for (final Integer dataSeries : tMap.keySet()) {
+            ITF8.writeUnsignedITF8(tagEncodingMap.size(), mapBuffer);
+            for (final Integer dataSeries : tagEncodingMap.keySet()) {
                 ITF8.writeUnsignedITF8(dataSeries, mapBuffer);
 
-                final EncodingParams params = tMap.get(dataSeries);
-                mapBuffer.put((byte) (0xFF & params.id.getId()));
-                ITF8.writeUnsignedITF8(params.params.length, mapBuffer);
-                mapBuffer.put(params.params);
+                final EncodingDescriptor params = tagEncodingMap.get(dataSeries);
+                mapBuffer.put((byte) (0xFF & params.getEncodingID().getId()));
+                ITF8.writeUnsignedITF8(params.getEncodingParameters().length, mapBuffer);
+                mapBuffer.put(params.getEncodingParameters());
             }
             mapBuffer.flip();
             final byte[] mapBytes = new byte[mapBuffer.limit()];
@@ -294,26 +330,4 @@ public class CompressionHeader {
         }
     }
 
-    /**
-     * Read a COMPRESSION_HEADER Block from an InputStream and return its contents as a CompressionHeader
-     * We do this instead of reading the InputStream directly because the Block content may be compressed
-     *
-     * @param cramVersion the CRAM version
-     * @param blockStream the stream to read from
-     * @return a new CompressionHeader from the input
-     */
-    public static CompressionHeader read(final int cramVersion, final InputStream blockStream) {
-        final Block block = Block.read(cramVersion, blockStream);
-        if (block.getContentType() != BlockContentType.COMPRESSION_HEADER)
-            throw new RuntimeIOException("Compression Header Block expected, found: " + block.getContentType().name());
-
-        try (final ByteArrayInputStream internalStream = new ByteArrayInputStream(block.getUncompressedContent())) {
-            final CompressionHeader header = new CompressionHeader();
-            header.internalRead(internalStream);
-            return header;
-        } catch (final IOException e) {
-            throw new RuntimeIOException(e);
-        }
-    }
-
 }
