@@ -32,7 +32,11 @@ public enum BlockCompressionMethod {
     GZIP(1),
     BZIP2(2),
     LZMA(3),
-    RANS(4);
+    RANS(4), // rAns 4x8
+    RANSNx16(5),
+    ADAPTIVE_ARITHMETIC(6),
+    FQZCOMP(7),
+    NAME_TOKENISER(8);
 
     private final int methodId;
 
@@ -65,4 +69,4 @@ public enum BlockCompressionMethod {
     private static final Map<Integer, BlockCompressionMethod> ID_MAP =
             Collections.unmodifiableMap(Stream.of(BlockCompressionMethod.values())
                     .collect(Collectors.toMap(BlockCompressionMethod::getMethodId, Function.identity())));
-}
+}
\ No newline at end of file
