@@ -95,9 +95,6 @@ abstract public class AbstractProgressLogger implements ProgressLoggerInterface
     protected synchronized boolean record(final String chrom, final int pos, final String rname) {
         if (chrom != null && chrom.equals(lastChrom) && pos < lastPos) {
             countNonIncreasing++;
-            if (countNonIncreasing == PRINT_READ_NAME_THRESHOLD) {
-                log("Seen many non-increasing record positions. Printing Read-names as well.");
-            }
         } else {
             lastChrom = chrom;
         }
