@@ -23,6 +23,7 @@
  */
 package htsjdk.tribble.bed;
 
+import htsjdk.samtools.util.FileExtensions;
 import htsjdk.samtools.util.IOUtil;
 import htsjdk.tribble.AbstractFeatureReader;
 import htsjdk.tribble.AsciiFeatureCodec;
@@ -43,7 +44,11 @@ import java.util.regex.Pattern;
 public class BEDCodec extends AsciiFeatureCodec<BEDFeature> {
 
     /** Default extension for BED files. */
-    public static final String BED_EXTENSION = ".bed";
+    /**
+     * @deprecated since June 2019 Use {@link FileExtensions#BED} instead.
+     */
+    @Deprecated
+    public static final String BED_EXTENSION = FileExtensions.BED;
 
     private static final Pattern SPLIT_PATTERN = Pattern.compile("\\t|( +)");
     private final int startOffsetValue;
@@ -235,7 +240,7 @@ public class BEDCodec extends AsciiFeatureCodec<BEDFeature> {
         } else {
             toDecode = path;
         }
-        return toDecode.toLowerCase().endsWith(BED_EXTENSION);
+        return toDecode.toLowerCase().endsWith(FileExtensions.BED);
     }
 
     public int getStartOffset() {
