@@ -22,6 +22,7 @@ import java.net.URLDecoder;
 import java.nio.file.Files;
 import java.nio.file.Path;
 import java.util.*;
+import java.util.function.Predicate;
 import java.util.regex.Pattern;
 import java.util.zip.GZIPInputStream;
 
@@ -71,20 +72,38 @@ public class Gff3Codec extends AbstractFeatureCodec<Gff3Feature, LineIterator> {
 
     private int currentLine = 0;
 
+    /** filter to removing keys from the EXTRA_FIELDS column */
+    private final Predicate<String> filterOutAttribute;
+    
     public Gff3Codec() {
         this(DecodeDepth.DEEP);
     }
 
     public Gff3Codec(final DecodeDepth decodeDepth) {
+        this(decodeDepth, KEY -> false);
+    }
+
+    /**
+     * @param decodeDepth a value from DecodeDepth
+     * @param filterOutAttribute  filter to remove keys from the EXTRA_FIELDS column
+     */
+    public Gff3Codec(final DecodeDepth decodeDepth, final Predicate<String> filterOutAttribute) {
         super(Gff3Feature.class);
         this.decodeDepth = decodeDepth;
+        this.filterOutAttribute = filterOutAttribute;
+        /* check required keys are always kept */
+        for (final String key : new String[] {Gff3Constants.PARENT_ATTRIBUTE_KEY, Gff3Constants.ID_ATTRIBUTE_KEY, Gff3Constants.NAME_ATTRIBUTE_KEY}) {
+            if (filterOutAttribute.test(key)) {
+                throw new IllegalArgumentException("Predicate should always accept " + key);
+                }
+        }
     }
 
     public enum DecodeDepth {
         DEEP ,
         SHALLOW
     }
-
+    
     @Override
     public Gff3Feature decode(final LineIterator lineIterator) throws IOException {
         return decode(lineIterator, decodeDepth);
@@ -129,7 +148,7 @@ public class Gff3Codec extends AbstractFeatureCodec<Gff3Feature, LineIterator> {
 
 
 
-        final Gff3FeatureImpl thisFeature = new Gff3FeatureImpl(parseLine(line, currentLine));
+        final Gff3FeatureImpl thisFeature = new Gff3FeatureImpl(parseLine(line, currentLine, this.filterOutAttribute));
         activeFeatures.add(thisFeature);
         if (depth == DecodeDepth.DEEP) {
             //link to parents/children/co-features
@@ -200,7 +219,7 @@ public class Gff3Codec extends AbstractFeatureCodec<Gff3Feature, LineIterator> {
         return attributes;
     }
 
-    static private Gff3BaseData parseLine(final String line, final int currentLine) {
+    private static Gff3BaseData parseLine(final String line, final int currentLine, final Predicate<String> filterOutAttribute) {
         final List<String> splitLine = ParsingUtils.split(line, Gff3Constants.FIELD_DELIMITER);
 
         if (splitLine.size() != NUM_FIELDS) {
@@ -217,6 +236,8 @@ public class Gff3Codec extends AbstractFeatureCodec<Gff3Feature, LineIterator> {
             final int phase = splitLine.get(GENOMIC_PHASE_INDEX).equals(Gff3Constants.UNDEFINED_FIELD_VALUE) ? -1 : Integer.parseInt(splitLine.get(GENOMIC_PHASE_INDEX));
             final Strand strand = Strand.decode(splitLine.get(GENOMIC_STRAND_INDEX));
             final Map<String, List<String>> attributes = parseAttributes(splitLine.get(EXTRA_FIELDS_INDEX));
+            /* remove attibutes matching 'filterOutAttribute' */
+            attributes.keySet().removeIf(filterOutAttribute);
             return new Gff3BaseData(contig, source, type, start, end, score, strand, phase, attributes);
         } catch (final NumberFormatException ex ) {
             throw new TribbleException("Cannot read integer value for start/end position from line " + currentLine + ".  Line is: " + line, ex);
