@@ -9,7 +9,8 @@ public class SequenceRegion implements Locatable {
     private final int start;
     private final int end;
     private final String contig;
-    private boolean isCircular;
+    private Boolean isCircular;
+    private int hashCode;
 
     SequenceRegion(final String contig, final int start, final int end) {
         this(contig, start, end, false);
@@ -20,10 +21,12 @@ public class SequenceRegion implements Locatable {
         this.start = start;
         this.end = end;
         this.isCircular = isCircular;
+        hashCode = computeHashCode();
     }
 
     void setCircular(final boolean isCircular) {
         this.isCircular = isCircular;
+        hashCode = computeHashCode();
     }
 
     void setCircular() {
@@ -41,9 +44,28 @@ public class SequenceRegion implements Locatable {
 
     public boolean isCircular(){return  isCircular;}
 
-    public boolean equals(final SequenceRegion other) {
-        return other.start == start && other.end==end && other.contig.equals(contig) && other.isCircular == isCircular;
+    @Override
+    public boolean equals(Object other) {
+        if (other == this) {
+            return true;
+        }
+
+        if (!(other instanceof SequenceRegion)) {
+            return false;
+        }
+
+        final SequenceRegion otherSequenceRegion = (SequenceRegion) other;
+        return otherSequenceRegion.start == start && otherSequenceRegion.end==end && otherSequenceRegion.contig.equals(contig) && otherSequenceRegion.isCircular == isCircular;
     }
 
+    private int computeHashCode() {
+        int hash = contig.hashCode();
+        hash = 31 * hash + start;
+        hash = 31 * hash + end;
+        hash = 31 * hash + isCircular.hashCode();
+        return hash;
+    }
 
+    @Override
+    public int hashCode() { return hashCode;}
 }
