@@ -27,8 +27,8 @@ import htsjdk.samtools.seekablestream.ISeekableStreamFactory;
 import htsjdk.samtools.seekablestream.SeekableStream;
 import htsjdk.samtools.seekablestream.SeekableStreamFactory;
 import htsjdk.samtools.util.BlockCompressedInputStream;
+import htsjdk.samtools.util.FileExtensions;
 import htsjdk.tribble.util.ParsingUtils;
-import htsjdk.tribble.util.TabixUtils;
 
 import java.io.IOException;
 import java.io.InputStream;
@@ -45,7 +45,7 @@ import java.util.function.Function;
 /**
  * @author Heng Li <hengli@broadinstitute.org>
  */
-public class TabixReader {
+public class TabixReader implements AutoCloseable {
     private final String mFilePath;
     private final String mIndexPath;
     private final Function<SeekableByteChannel, SeekableByteChannel> mIndexWrapper;
@@ -158,7 +158,7 @@ public class TabixReader {
         mFp = new BlockCompressedInputStream(stream);
         mIndexWrapper = indexWrapper;
         if(indexPath == null){
-            mIndexPath = ParsingUtils.appendToPath(filePath, TabixUtils.STANDARD_INDEX_EXTENSION);
+            mIndexPath = ParsingUtils.appendToPath(filePath, FileExtensions.TABIX_INDEX);
         } else {
             mIndexPath = indexPath;
         }
@@ -446,16 +446,16 @@ public class TabixReader {
     }
 
     /**
-     * Return
-     * @param tid Sequence id
-     * @param beg beginning of interval, genomic coords
-     * @param end end of interval, genomic coords
-     * @return an iterator over the lines within the specified interval
+     * Get an iterator for an interval specified by the sequence id and begin and end coordinates
+     * @param tid Sequence id, if non-existent returns EOF_ITERATOR
+     * @param beg beginning of interval, genomic coords (0-based, closed-open)
+     * @param end end of interval, genomic coords (0-based, closed-open)
+     * @return an iterator over the specified interval
      */
     public Iterator query(final int tid, final int beg, final int end) {
         TPair64[] off, chunks;
         long min_off;
-        if(tid< 0 || tid>=this.mIndex.length) return EOF_ITERATOR;
+        if (tid < 0 || beg < 0 || end <= 0 || tid >= this.mIndex.length) return EOF_ITERATOR;
         TIndex idx = mIndex[tid];
         int[] bins = new int[MAX_BIN];
         int i, l, n_off, n_bins = reg2bins(beg, end, bins);
@@ -510,30 +510,29 @@ public class TabixReader {
      *
      * @see #parseReg(String)
      * @param reg A region string of the form acceptable by {@link #parseReg(String)}
-     * @return
+     * @return an iterator over the specified interval
      */
     public Iterator query(final String reg) {
         int[] x = parseReg(reg);
-        if(x[0]<0) return EOF_ITERATOR;
         return query(x[0], x[1], x[2]);
     }
 
     /**
-    *
+    * Get an iterator for an interval specified by the sequence id and begin and end coordinates
     * @see #parseReg(String)
     * @param reg a chromosome
     * @param start start interval
     * @param end end interval
-    * @return a tabix iterator
+    * @return a tabix iterator over the specified interval
     */
-   public Iterator query(final String reg,int start,int end) {
-       int tid=this.chr2tid(reg);
-       if(tid==-1) return EOF_ITERATOR;
+   public Iterator query(final String reg, int start, int end) {
+       int tid = this.chr2tid(reg);
        return query(tid, start, end);
    }
 
     // ADDED BY JTR
-    public void close() {
+   @Override 
+   public void close() {
         if(mFp != null) {
             try {
                 mFp.close();
@@ -543,8 +542,8 @@ public class TabixReader {
         }
     }
 
-    @Override
-    public String toString() {
+   @Override
+   public String toString() {
         return "TabixReader: filename:"+getSource();
-    }
+   }
 }
