@@ -28,6 +28,7 @@ package htsjdk.variant.variantcontext;
 
 import htsjdk.tribble.util.ParsingUtils;
 import htsjdk.variant.vcf.VCFConstants;
+import htsjdk.variant.vcf.VCFUtils;
 
 import java.io.Serializable;
 import java.util.ArrayList;
@@ -76,6 +77,20 @@ public abstract class Genotype implements Comparable<Genotype>, Serializable {
      */
     public abstract List<Allele> getAlleles();
 
+    /**
+     * @return true if any allele is REF
+     */
+    public boolean hasRefAllele() {
+        return getAlleles().stream().anyMatch(A->A.isReference());
+    };
+
+    /**
+     * @return true if any allele is ALT, (NO_CALL are ignored)
+     */
+    public boolean hasAltAllele() {
+        return getAlleles().stream().anyMatch(A->!(A.isReference() || A.isNoCall()));
+    };
+
     /**
      * Returns how many times allele appears in this genotype object?
      *
@@ -518,7 +533,7 @@ public abstract class Genotype implements Comparable<Genotype>, Serializable {
         Object x = getExtendedAttribute(key);
         if ( x == null || x == VCFConstants.MISSING_VALUE_v4 ) return defaultValue;
         if ( x instanceof Integer ) return (Integer)x;
-        return Integer.valueOf((String)x); // throws an exception if this isn't a string
+        return Integer.parseInt((String)x); // throws an exception if this isn't a string
     }
 
     @Deprecated
@@ -526,7 +541,7 @@ public abstract class Genotype implements Comparable<Genotype>, Serializable {
         Object x = getExtendedAttribute(key);
         if ( x == null ) return defaultValue;
         if ( x instanceof Double ) return (Double)x;
-        return Double.valueOf((String)x); // throws an exception if this isn't a string
+        return VCFUtils.parseVcfDouble((String) x); // throws an exception if this isn't a string
     }
 
     /**
