@@ -159,7 +159,9 @@ public class VCFHeaderLine implements Comparable, Serializable {
             builder.append('=');
             builder.append(entry.getValue().toString().contains(",") ||
                            entry.getValue().toString().contains(" ") ||
-                           entry.getKey().equals("Description") ? "\""+ escapeQuotes(entry.getValue().toString()) + "\"" : entry.getValue());
+                           entry.getKey().equals("Description") ||
+                           entry.getKey().equals("Source") || // As per VCFv4.2, Source and Version should be surrounded by double quotes
+                           entry.getKey().equals("Version") ? "\""+ escapeQuotes(entry.getValue().toString()) + "\"" : entry.getValue());
         }
         builder.append('>');
         return builder.toString();
@@ -172,4 +174,4 @@ public class VCFHeaderLine implements Comparable, Serializable {
         // with: the thing that wasn't a backslash ($1), followed by a backslash, followed by a double quote
         return value.replaceAll("([^\\\\])\"", "$1\\\\\"");
     }
-}
\ No newline at end of file
+}
