@@ -25,9 +25,11 @@ package htsjdk.samtools;
 
 import htsjdk.HtsjdkTest;
 import htsjdk.samtools.cram.ref.ReferenceSource;
+import htsjdk.samtools.reference.IndexedFastaSequenceFile;
 import htsjdk.samtools.util.BinaryCodec;
 import htsjdk.samtools.util.CloserUtil;
 import org.testng.Assert;
+import org.testng.annotations.BeforeTest;
 import org.testng.annotations.DataProvider;
 import org.testng.annotations.Test;
 
@@ -48,6 +50,9 @@ import java.util.Map;
  */
 public class SAMIntegerTagTest extends HtsjdkTest {
     private static final File TEST_DATA_DIR = new File("src/test/resources/htsjdk/samtools/SAMIntegerTagTest");
+    private static final File REF_FILE = new File("src/test/resources/htsjdk/samtools/reference/Homo_sapiens_assembly18.trimmed.fasta");
+    private SAMSequenceDictionary DICTIONARY_BACKED_BY_REF_FILE;
+
 
     private static final String BYTE_TAG = "BY";
     private static final String SHORT_TAG = "SH";
@@ -57,7 +62,14 @@ public class SAMIntegerTagTest extends HtsjdkTest {
 
     private static final long TOO_LARGE_UNSIGNED_INT_VALUE = BinaryCodec.MAX_UINT + 1L;
 
-    enum FORMAT {SAM, BAM, CRAM}
+    enum Format {SAM, BAM, CRAM}
+
+    @BeforeTest
+    public void loadDictionaryFromFasta () throws IOException {
+        final IndexedFastaSequenceFile ff = new IndexedFastaSequenceFile(REF_FILE);
+        DICTIONARY_BACKED_BY_REF_FILE = ff.getSequenceDictionary();
+        ff.close();
+    }
 
     @Test
     public void testBAM() throws Exception {
@@ -209,19 +221,23 @@ public class SAMIntegerTagTest extends HtsjdkTest {
      */
     private SAMRecord writeAndReadSamRecord(final String format, SAMRecord rec) throws IOException {
         final File bamFile = File.createTempFile("htsjdk-writeAndReadSamRecord.", "." + format);
-        final SAMFileWriter bamWriter = new SAMFileWriterFactory().makeSAMOrBAMWriter(rec.getHeader(), false, bamFile);
+        final SAMFileWriter bamWriter = new SAMFileWriterFactory().makeWriter(rec.getHeader(), false, bamFile, REF_FILE);
         bamWriter.addAlignment(rec);
         bamWriter.close();
-        final SamReader reader = SamReaderFactory.makeDefault().open(bamFile);
-        rec = reader.iterator().next();
-        reader.close();
+
+        try(final SamReader reader = SamReaderFactory.makeDefault().referenceSequence(REF_FILE).open(bamFile);
+            final SAMRecordIterator iterator = reader.iterator()) {
+            Assert.assertTrue(iterator.hasNext());
+            rec = iterator.next();
+        }
         bamFile.delete();
         return rec;
     }
 
-    private SAMRecord createSamRecord() {
+    private SAMRecord createSamRecord() throws IOException {
         final SAMRecordSetBuilder builder = new SAMRecordSetBuilder(false, SAMFileHeader.SortOrder.unsorted);
-        builder.addFrag("readA", 20, 140, false);
+        builder.getHeader().setSequenceDictionary(DICTIONARY_BACKED_BY_REF_FILE);
+        builder.addFrag("readA", 0, 140, false);
         return builder.iterator().next();
     }
 
@@ -250,14 +266,16 @@ public class SAMIntegerTagTest extends HtsjdkTest {
 
     @Test(expectedExceptions = SAMException.class)
     public void testBadSamStrict() throws IOException {
-        final SamReader reader = SamReaderFactory.makeDefault().validationStringency(ValidationStringency.STRICT).open(createSamForIntAttr(BinaryCodec.MAX_UINT + 1L));
-        reader.iterator().next();
+        try(final SamReader reader = SamReaderFactory.makeDefault().validationStringency(ValidationStringency.STRICT).open(createSamForIntAttr(BinaryCodec.MAX_UINT + 1L))) {
+            reader.iterator().next();
+        }
     }
 
     @Test
     public void testBadSamSilent() throws IOException {
-        final SamReader reader = SamReaderFactory.makeDefault().validationStringency(ValidationStringency.SILENT).open(createSamForIntAttr(BinaryCodec.MAX_UINT + 1L));
-        reader.iterator().next();
+        try(final SamReader reader = SamReaderFactory.makeDefault().validationStringency(ValidationStringency.SILENT).open(createSamForIntAttr(BinaryCodec.MAX_UINT + 1L))) {
+            reader.iterator().next();
+        }
     }
 
     @DataProvider(name = "legalIntegerAttributesFiles")
@@ -293,8 +311,8 @@ public class SAMIntegerTagTest extends HtsjdkTest {
 
     @DataProvider(name = "valid_set")
     public static Object[][] valid_set() {
-        List<Object[]> params = new ArrayList<Object[]>();
-        for (FORMAT format:FORMAT.values()) {
+        final List<Object[]> params = new ArrayList<Object[]>();
+        for (Format format: Format.values()) {
             for (ValidationStringency stringency:ValidationStringency.values()) {
                 params.add(new Object[]{0, format, stringency});
                 params.add(new Object[]{1, format, stringency});
@@ -314,8 +332,8 @@ public class SAMIntegerTagTest extends HtsjdkTest {
 
     @DataProvider(name = "invalid_set")
     public static Object[][] invalid_set() {
-        List<Object[]> params = new ArrayList<Object[]>();
-        for (FORMAT format:FORMAT.values()) {
+        final List<Object[]> params = new ArrayList<Object[]>();
+        for (Format format: Format.values()) {
             for (ValidationStringency stringency:ValidationStringency.values()) {
                 params.add(new Object[]{(long)Integer.MIN_VALUE -1L, format, stringency});
                 params.add(new Object[]{TOO_LARGE_UNSIGNED_INT_VALUE, format, stringency});
@@ -326,18 +344,18 @@ public class SAMIntegerTagTest extends HtsjdkTest {
     }
 
     @Test(dataProvider = "valid_set")
-    public void testValidIntegerAttributeRoundtrip(final long value, final FORMAT format, ValidationStringency validationStringency) throws IOException {
+    public void testValidIntegerAttributeRoundtrip(final long value, final Format format, ValidationStringency validationStringency) throws IOException {
         testRoundtripIntegerAttribute(value, format, validationStringency);
     }
 
     @Test(dataProvider = "invalid_set", expectedExceptions = RuntimeException.class)
-    public void testInvalidIntegerAttributeRoundtrip(final long value, final FORMAT format, ValidationStringency validationStringency) throws IOException {
+    public void testInvalidIntegerAttributeRoundtrip(final long value, final Format format, ValidationStringency validationStringency) throws IOException {
         testRoundtripIntegerAttribute(value, format, validationStringency);
     }
 
-    private void testRoundtripIntegerAttribute(final Number value, final FORMAT format, ValidationStringency validationStringency) throws IOException {
+    private void testRoundtripIntegerAttribute(final Number value, final Format format, ValidationStringency validationStringency) throws IOException {
         final SAMFileHeader header = new SAMFileHeader();
-        ByteArrayOutputStream baos = new ByteArrayOutputStream();
+        final ByteArrayOutputStream baos = new ByteArrayOutputStream();
 
         final SAMFileWriter w;
         switch (format) {
