@@ -27,6 +27,7 @@ package htsjdk.samtools;
 import htsjdk.HtsjdkTest;
 import htsjdk.samtools.util.CloserUtil;
 import org.testng.Assert;
+import org.testng.annotations.DataProvider;
 import org.testng.annotations.Test;
 
 import java.io.File;
@@ -35,50 +36,49 @@ import java.util.ArrayList;
 import java.util.List;
 
 public class SamSpecIntTest extends HtsjdkTest {
-    private static final File SAM_INPUT = new File("src/test/resources/htsjdk/samtools/inttest.sam");
-    private static final File BAM_INPUT = new File("src/test/resources/htsjdk/samtools/inttest.bam");
+    private static final File TEST_DATA_DIR = new File("src/test/resources/htsjdk/samtools");
 
-    @Test
-    public void testSamIntegers() throws IOException {
-        final List<String> errorMessages = new ArrayList<String>();
-        final SamReader samReader = SamReaderFactory.makeDefault().open(SAM_INPUT);
-        final File bamOutput = File.createTempFile("test", ".bam");
-        final File samOutput = File.createTempFile("test", ".sam");
-        final SAMFileWriter samWriter = new SAMFileWriterFactory().makeWriter(samReader.getFileHeader(), true, samOutput, null);
-        final SAMFileWriter bamWriter = new SAMFileWriterFactory().makeWriter(samReader.getFileHeader(), true, bamOutput, null);
-
-        final SAMRecordIterator iterator = samReader.iterator();
-        while (iterator.hasNext()) {
-            try {
-                final SAMRecord rec = iterator.next();
-                samWriter.addAlignment(rec);
-                bamWriter.addAlignment(rec);
-            } catch (final Throwable e) {
-                System.out.println(e.getMessage());
-                errorMessages.add(e.getMessage());
-            }
-        }
-
-        CloserUtil.close(samReader);
-        samWriter.close();
-        bamWriter.close();
-        Assert.assertEquals(errorMessages.size(), 0);
-        bamOutput.deleteOnExit();
-        samOutput.deleteOnExit();
+    @DataProvider(name = "testSamIntegersTestCases")
+    public Object[][] testSamIntegersTestCases() {
+        return new Object[][]{
+                {"inttest.sam"},
+                {"inttest_large_coordinates.sam"}
+        };
     }
 
-    @Test
-    public void testBamIntegers() throws IOException {
-        final List<String> errorMessages = new ArrayList<String>();
-        final SamReader bamReader = SamReaderFactory.makeDefault().open(BAM_INPUT);
+    @DataProvider(name = "testBamIntegersTestCases")
+    public Object[][] testBamIntegersTestCases() {
+        return new Object[][]{
+                {"inttest.bam"},
+                {"inttest_large_coordinates.bam"}
+        };
+    }
+
+    @Test(dataProvider = "testSamIntegersTestCases")
+    public void testSamIntegers(final String inputFile) throws IOException {
+        final File input = new File(TEST_DATA_DIR, inputFile);
+        final SamReader samReader = SamReaderFactory.makeDefault().open(input);
+
+        tryToWriteToSamAndBam(samReader);
+    }
+
+    @Test(dataProvider = "testBamIntegersTestCases")
+    public void testBamIntegers(final String inputFile) throws IOException {
+        final File input = new File(TEST_DATA_DIR, inputFile);
+        final SamReader bamReader = SamReaderFactory.makeDefault().open(input);
+
+        tryToWriteToSamAndBam(bamReader);
+    }
+
+    private void tryToWriteToSamAndBam(final SamReader reader) throws IOException {
         final File bamOutput = File.createTempFile("test", ".bam");
         final File samOutput = File.createTempFile("test", ".sam");
-        final SAMFileWriter samWriter = new SAMFileWriterFactory().makeWriter(bamReader.getFileHeader(), true, samOutput, null);
-        final SAMFileWriter bamWriter = new SAMFileWriterFactory().makeWriter(bamReader.getFileHeader(), true, bamOutput, null);
-        final SAMRecordIterator iterator = bamReader.iterator();
-        while (iterator.hasNext()) {
+        final SAMFileWriter samWriter = new SAMFileWriterFactory().makeWriter(reader.getFileHeader(), true, samOutput, null);
+        final SAMFileWriter bamWriter = new SAMFileWriterFactory().makeWriter(reader.getFileHeader(), true, bamOutput, null);
+
+        final List<String> errorMessages = new ArrayList<>();
+        for (SAMRecord rec : reader) {
             try {
-                final SAMRecord rec = iterator.next();
                 samWriter.addAlignment(rec);
                 bamWriter.addAlignment(rec);
             } catch (final Throwable e) {
@@ -87,7 +87,7 @@ public class SamSpecIntTest extends HtsjdkTest {
             }
         }
 
-        CloserUtil.close(bamReader);
+        CloserUtil.close(reader);
         samWriter.close();
         bamWriter.close();
         Assert.assertEquals(errorMessages.size(), 0);
