@@ -702,4 +702,65 @@ public class IntervalListTest extends HtsjdkTest {
     public void testBreaks(final Path brokenIntervalFile){
         IntervalList.fromPath(brokenIntervalFile);
     }
+
+    @Test
+    public void testLargeIteratorMerge() {
+        final IntervalList intervals = new IntervalList(this.fileHeader);
+        intervals.add(new Interval("1", 1, 2, false, "foo"));
+        for (int i = 2; i < 100000; i++) {
+            intervals.add(new Interval("1", i, i + 1, false, "bar"));
+        }
+        final Interval merged = new IntervalList.IntervalMergerIterator(intervals.iterator(), true, false, false).next();
+        Assert.assertEquals(merged, new Interval("1", 1, 100000));
+        Assert.assertEquals(merged.getName(), "foo");
+    }
+
+    @DataProvider
+    public static Object[][] lessMemForMergeWithNoNames() {
+        String contig = "1";
+        Interval interval1 = new Interval(contig, 1, 100, false, "foo");
+        Interval interval2 = new Interval(contig, 101, 200, false, "bar");
+        Interval interval3 = new Interval(contig, 301, 400, false, "baz");
+        Interval overlapInterval = new Interval(contig, 350, 450, false, "overlap");
+        Interval interval4 = new Interval(contig, 401, 500, false, "qux");
+        Interval combined1NoConcat = new Interval(contig, 1, 200, false, "foo");
+        Interval combined2NoConcat = new Interval(contig, 301, 500, false, "baz");
+        Interval combined1WithConcat = new Interval(contig, 1, 200, false, "foo|bar");
+        Interval combined2WithConcat = new Interval(contig, 301, 500, false, "baz|qux");
+        Interval combined2WithConcatAndOverlap = new Interval(contig, 301, 500, false, "baz|overlap|qux");
+        return new Object[][]{
+                {Collections.emptyList(), Collections.emptyList(), Collections.emptyList()},
+                {Arrays.asList(interval1), Arrays.asList(interval1), Arrays.asList(interval1)},
+                {Arrays.asList(interval1, interval2), Arrays.asList(combined1NoConcat), Arrays.asList(combined1WithConcat)},
+                {Arrays.asList(interval1, interval2, interval3), Arrays.asList(combined1NoConcat, interval3), Arrays.asList(combined1WithConcat, interval3)},
+                {Arrays.asList(interval1, interval2, interval3, interval4), Arrays.asList(combined1NoConcat, combined2NoConcat), Arrays.asList(combined1WithConcat, combined2WithConcat)},
+                {Arrays.asList(interval1, interval2, interval3, overlapInterval, interval4), Arrays.asList(combined1NoConcat, combined2NoConcat), Arrays.asList(combined1WithConcat, combined2WithConcatAndOverlap)}
+        };
+    }
+
+    @Test(dataProvider = "lessMemForMergeWithNoNames")
+    public void testLessMemForMergeWithNoNames(final List<Interval> intervals, final List<Interval> expectedNoConcat, final List<Interval> expectedWithConcat) {
+        final IntervalList intervalList = new IntervalList(this.fileHeader);
+        intervalList.addall(intervals);
+
+        final IntervalList.IntervalMergerIterator firstNameMergerIterator = new IntervalList.IntervalMergerIterator(intervals.iterator(), true, false, false);
+        Collection<Interval> firstNameMerged = CollectionUtil.makeCollection(firstNameMergerIterator);
+        Assert.assertEquals(firstNameMerged, expectedNoConcat);
+        List<Interval> firstNameMergedList = new ArrayList<>(firstNameMerged);
+        for(int i=0; i<firstNameMergedList.size(); i++){
+            Interval actual = firstNameMergedList.get(i);
+            Interval expected = expectedNoConcat.get(i);
+            Assert.assertEquals(actual.getName(), expected.getName());
+        }
+
+        final IntervalList.IntervalMergerIterator concatNameMergerIterator = new IntervalList.IntervalMergerIterator(intervals.iterator(), true, false, true);
+        Collection<Interval> concatNameMerged = CollectionUtil.makeCollection(concatNameMergerIterator);
+        Assert.assertEquals(concatNameMerged, expectedWithConcat);
+        List<Interval> allNamesMergedList = new ArrayList<>(concatNameMerged);
+        for(int i=0; i<allNamesMergedList.size(); i++){
+            Interval actual = allNamesMergedList.get(i);
+            Interval expected = expectedWithConcat.get(i);
+            Assert.assertEquals(actual.getName(), expected.getName());
+        }
+    }
 }
