@@ -79,11 +79,14 @@ public class TabixReaderTest extends HtsjdkTest {
         iter=tabixReader.query("UN:1-100");
         Assert.assertNotNull(iter);
         Assert.assertNull(iter.next());
-       
-        
+
         iter=tabixReader.query("1:10-1");
         Assert.assertNotNull(iter);
         Assert.assertNull(iter.next());
+
+        iter=tabixReader.query("chr2:0-1");
+        Assert.assertNotNull(iter);
+        Assert.assertNull(iter.next());
  
         iter=tabixReader.query(999999,9,9);
         Assert.assertNotNull(iter);
@@ -92,9 +95,36 @@ public class TabixReaderTest extends HtsjdkTest {
         iter=tabixReader.query("1",Integer.MAX_VALUE-1,Integer.MAX_VALUE);
         Assert.assertNotNull(iter);
         Assert.assertNull(iter.next());
-        
+
+        iter = tabixReader.query("1", -1, Integer.MAX_VALUE);
+        Assert.assertNotNull(iter);
+        Assert.assertNull(iter.next());
+
+        iter = tabixReader.query("1", Integer.MAX_VALUE, -1);
+        Assert.assertNotNull(iter);
+        Assert.assertNull(iter.next());
+
+        iter = tabixReader.query("1", Integer.MAX_VALUE, 0);
+        Assert.assertNotNull(iter);
+        Assert.assertNull(iter.next());
+
+        iter = tabixReader.query("1:100-1000");
+        Assert.assertNotNull(iter);
+        Assert.assertNotNull(iter.next());
+        Assert.assertNull(iter.next());
+
         final int pos_snp_in_vcf_chr1=327;
-        
+
+        iter = tabixReader.query("1:" + pos_snp_in_vcf_chr1 + "-" + pos_snp_in_vcf_chr1);
+        Assert.assertNotNull(iter);
+        Assert.assertNotNull(iter.next());
+        Assert.assertNull(iter.next());
+
+        iter = tabixReader.query("1:" + pos_snp_in_vcf_chr1);
+        Assert.assertNotNull(iter);
+        Assert.assertNotNull(iter.next());
+        Assert.assertNull(iter.next());
+
         iter=tabixReader.query("1",pos_snp_in_vcf_chr1,pos_snp_in_vcf_chr1);
         Assert.assertNotNull(iter);
         Assert.assertNotNull(iter);
@@ -107,7 +137,6 @@ public class TabixReaderTest extends HtsjdkTest {
         iter=tabixReader.query("1",pos_snp_in_vcf_chr1+1,pos_snp_in_vcf_chr1+1);
         Assert.assertNotNull(iter);
         Assert.assertNull(iter.next());
-
     }
     
     
@@ -143,19 +172,18 @@ public class TabixReaderTest extends HtsjdkTest {
     public void testRemoteQuery() throws IOException {
         String tabixFile = TestUtil.BASE_URL_FOR_HTTP_TESTS +"igvdata/tabix/trioDup.vcf.gz";
 
-        TabixReader tabixReader = new TabixReader(tabixFile);
-
-        TabixIteratorLineReader lineReader = new TabixIteratorLineReader(
-                tabixReader.query(tabixReader.chr2tid("4"), 320, 330));
-
-        int nRecords = 0;
-        String nextLine;
-        while ((nextLine = lineReader.readLine()) != null) {
-            Assert.assertTrue(nextLine.startsWith("4"));
-            nRecords++;
+        try(TabixReader tabixReader = new TabixReader(tabixFile)) {
+            TabixIteratorLineReader lineReader = new TabixIteratorLineReader(
+                    tabixReader.query(tabixReader.chr2tid("4"), 320, 330));
+    
+            int nRecords = 0;
+            String nextLine;
+            while ((nextLine = lineReader.readLine()) != null) {
+                Assert.assertTrue(nextLine.startsWith("4"));
+                nRecords++;
+            }
+            Assert.assertTrue(nRecords > 0);
         }
-        Assert.assertTrue(nRecords > 0);
-
     }
     
     /**
@@ -165,8 +193,8 @@ public class TabixReaderTest extends HtsjdkTest {
      */
     @Test
     public void testTabixReaderReadLine() throws IOException {
-        TabixReader tabixReader = new TabixReader(tabixFile);
-        Assert.assertNotNull(tabixReader.readLine());
-        tabixReader.close();
+        try(TabixReader tabixReader = new TabixReader(tabixFile)) {
+            Assert.assertNotNull(tabixReader.readLine());
+        }
     }
 }
